/* ProcessWatcher.java
 *
 * created: Mon Oct  4 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/diana/components/ProcessWatcher.java,v 1.1 1999/10/05 15:41:24 kmr Exp $
 */

package diana.components;

/**
 *  Objects of this class watch a Process object and then display a
 *  MessageFrame window when the process finishes.
 *
 *  @author Kim Rutherford
 *  @version $Id: ProcessWatcher.java,v 1.1 1999/10/05 15:41:24 kmr Exp $
 **/

public class ProcessWatcher extends Thread {
  /**
   *  Create a new ProcessWatcher object for the given Process.
   *  @param process The Process to watch.
   *  @param name The name of the process to watch.
   **/
  public ProcessWatcher (final Process process, final String name) {
    this.process = process;
    this.name = name;
  }

  /**
   *  This code will wait for the Process to finish then display the return
   *  value in a MessageFrame.
   **/
  public void run () {
    while (true) {
      try {
        final int return_value = process.waitFor ();

        if (return_value == 0) {
          new MessageFrame (name +
                            " completed successfully").setVisible (true);
          return;
        } else {
          new MessageFrame (name + " completed with error code: " +
                            return_value).setVisible (true);
          return;
        }
      } catch (InterruptedException e) {
        // go around the loop again
      }
    }
  }

  /**
   *  The Process reference that was passed to the constructor.
   **/
  final Process process;

  /**
   *  The program name that was passed to the constructor.
   **/
  final String name;
}
