/* GenbankFeatureTable.java
 *
 * created: Mon Sep 13 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/uk/ac/sanger/pathogens/embl/GenbankFeatureTable.java,v 1.3 1999/09/28 12:34:52 kmr Exp $
 */

package uk.ac.sanger.pathogens.embl;

import java.io.*;

/**
 *  A feature table that stores EMBL features.
 *
 *  @author Kim Rutherford
 *  @version $Id: GenbankFeatureTable.java,v 1.3 1999/09/28 12:34:52 kmr Exp $
 **/

class GenbankFeatureTable extends StreamFeatureTable {
  /**
   *  Create a new empty GenbankFeatureTable object.
   **/
  GenbankFeatureTable () {

  }

  /**
   *  Create a new GenbankFeatureTable object from the given FeatureTable.
   **/
  GenbankFeatureTable (final FeatureTable feature_table) {
    super (feature_table);
  }

  /**
   *  Create a new GenbankFeatureTable object from an embl stream.
   *  @param entry The Entry that owns this GenbankFeatureTable.
   *  @param in_stream The stream to read from.  When the constructor returns
   *    the stream will at the next line after the feature table.
   *  @exception InvalidRelationException Thrown if this Feature cannot contain
   *    the given Qualifier.
   **/
  GenbankFeatureTable (final GenbankDocumentEntry document_entry,
                       final LinePushBackReader in_stream)
      throws IOException, InvalidRelationException {
    super (in_stream);

    this.document_entry = document_entry;
    
    final FeatureEnumeration feature_enum = features ();

    while (feature_enum.hasMoreFeatures ()) {
      final GenbankStreamFeature new_feature =
        (GenbankStreamFeature) feature_enum.nextFeature ();
      
      new_feature.setDocumentEntry (document_entry);
    }
  }

  /**
   *  Add a feature to the feature table.  The features are ordered by first
   *  base and then last base.  This is an example ordering: 1..100, 1..200,
   *  50..100, 150..250.
   *  @param new_feature The feature to add
   **/
  void add (final Feature new_feature) {
    if (new_feature instanceof GenbankStreamFeature) {
      super.add (new_feature); 
    } else {
      super.add (new GenbankStreamFeature (new_feature));
    }
  }

  /**
   *  Add a source feature to the feature table.
   *  @param new_feature The source feature to add
   **/
  void addSourceFeature (final Feature new_feature) {
    if (new_feature instanceof GenbankStreamFeature) {
      super.addSourceFeature (new_feature); 
    } else {
      super.addSourceFeature (new GenbankStreamFeature (new_feature));
    }
  }

  /**
   *  Read and return a GenbankStreamFeature.  (called by
   *  FeatureTable.readFeatureFromStream ()).
   *  @param in_stream The stream to read from.  When the constructor returns
   *    the stream will at the next line after the feature table.
   *  @exception InvalidRelationException Thrown if this Feature cannot contain
   *    the given Qualifier.
   **/
  StreamFeature readFeatureFromStream (LinePushBackReader in_stream)
      throws IOException, InvalidRelationException {
    final GenbankStreamFeature new_feature =
      GenbankStreamFeature.readFromStream (in_stream);
    if (new_feature != null) {
      new_feature.setDocumentEntry (document_entry);
    }
    return new_feature;
  }

  /**
   *  The DocumentEntry that was passed to the constructor.
   **/
  private DocumentEntry document_entry = null;
}
