/* Key.java
 *
 * created: Sun Jan  3 1999
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 1998,1999  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/uk/ac/sanger/pathogens/embl/Key.java,v 1.2 1999/09/15 15:33:32 kmr Exp $
 */

package uk.ac.sanger.pathogens.embl;

import uk.ac.sanger.pathogens.*;

/**
 *  Each object in this class represents a feature key.  A key is a String
 *  with a limited number of possible values.
 *
 *  @author Kim Rutherford
 *  @version $Id: Key.java,v 1.2 1999/09/15 15:33:32 kmr Exp $
 **/

public class Key {
  /**
   *  A convenience copy of the CDS Key.
   **/
  public static final Key CDS = new Key ("CDS", true);

  /**
   *  Create a new Key object from the given String.
   *  @param key_string The text of the new Key.
   *  @exception InvalidKeyException Thrown if the String passed to the
   *    constructor is not a valid feature key.
   **/
  public Key (final String key_string)
      throws InvalidKeyException {

    if (!EntryInformation.isPossibleKey (key_string)) {
      throw new InvalidKeyException ("this is not a valid key: " + key_string);
    }

    this.key_string = key_string;
  }

  /**
   *  Create a new Key object from the given String without checking to see if
   *  the key_string is valid.
   *  @param key_string The text of the new Key.
   *  @param dummy This is present only to distinguish this constructor from
   *    the previous one.
   **/
  Key (final String key_string, final boolean dummy) {
    this.key_string = key_string;
  }
  
  /**
   *  Return the String reference that was passed to the constructor.
   **/
  public String getKeyString () {
    return key_string;
  }

  /**
   *  Return a String representation of this Key.  This currently does this
   *  same as getKeyString ().
   **/
  public String toString () {
    return getKeyString ();
  }

  /**
   *  Compares this Key to the specified object. The result is true if and
   *  only if the argument is not null and represents the same sequence of
   *  characters as the String that was passed to the constructor.
   **/
  public boolean equals (final String test_string) {
    return getKeyString ().equals (test_string);
  }

  /**
   *  Compares this Key to the given Key.  This is equivalent to
   *  this.toString ().equals (test_string.toString ());
   **/
  public boolean equals (final Key key) {
    return getKeyString ().equals (key.getKeyString ());
  }

  /**
   *  Return the length of the String that was passed to the constructor.
   **/
  public int length () {
    return getKeyString ().length ();
  }

  /**
   *  Return a vector containing the String representations of the possible
   *  keys.
   **/
  public static StringVector getPossibleKeys () {
    return EntryInformation.getPossibleKeys ();
  }

  /**
   *  The String that was passed to the constructor.
   **/
  private String key_string;
}


